/*
 * share/unistd.h
 */


#ifndef share_unistd_h
#define share_unistd_h


#ifndef ASM_FILE


#include<sys/types.h>


enum{
	/* Symbolic constants for the lseek() and fcntl() function. */
	SEEK_CUR=1,
	SEEK_END,
	SEEK_SET,

	/* Reboot flag. */
	REBOOT_REBOOT=0,
	REBOOT_POWEROFF,

	/* chattr() flag. */
	CHATTR_MODE=0,	/* modeѹ */
	CHATTR_UID,		/* uidѹ */
	CHATTR_GID,		/* gidѹ */
	CHATTR_UTIME,	/* ֤ȹ֤ѹ */
};


typedef struct{
	pid_t pid;
	pid_t pgid;
	pid_t ppid;
	uid_t uid;
	gid_t gid;
}PROC_ID;


#endif


#endif
